@@ -22,7 +22,7 @@
 ## GNU General Public License for more details.
 ##
 
-Version = '0.9.12-1'
+Version = '0.10.6-1'
 
 import os
 import sys
@@ -365,7 +365,7 @@ class smsconEditorMainWindow(QtGui.QMainWindow):
        '''Set GUI values from the current operation'''
        
        DAEMONSTATE = os.popen('sudo smscon -status').read().strip('\n') 
-       BOOTSTATE = IsFileReadable('/etc/event.d/smscon_boot')
+       BOOTSTATE = IsFileReadable(os.path.join(smscon.BootPath, smscon.BootFile))
        
        if DAEMONSTATE.endswith('running'):
           self.ui.btnStop.setEnabled(True)
@@ -682,6 +682,7 @@ class smsconEditorCommands(QtGui.QMainWindow):     ## Commands Renaming
         
        ##... and show all the commands without the prefix (and without the suffix).
        self.ui.lineCheck       .setText(comConf['COM_CHECK'])
+       self.ui.lineStolen      .setText(comConf['COM_STOLEN'])
        self.ui.lineLog         .setText(comConf["COM_LOG"])        ##reply the smscon.log
        self.ui.lineReboot      .setText(comConf['COM_REBOOT'])
        self.ui.linePowerOff    .setText(comConf['COM_POWEROFF'])
@@ -689,6 +690,8 @@ class smsconEditorCommands(QtGui.QMainWindow):     ## Commands Renaming
        self.ui.lineLocation    .setText(comConf['COM_LOCATION'])
        self.ui.lineRemoteOn    .setText(comConf['COM_REMOTEON'])
        self.ui.lineRemoteOff   .setText(comConf['COM_REMOTEOFF'])
+       self.ui.lineSilentOn    .setText(comConf['COM_SILENTON'])
+       self.ui.lineSilentOff   .setText(comConf['COM_SILENTOFF'])
        self.ui.lineCamera      .setText(comConf['COM_CAMERA'])
        self.ui.lineCall        .setText(comConf['COM_CALL'])
        self.ui.lineLock        .setText(comConf['COM_LOCK'])
@@ -714,6 +717,7 @@ class smsconEditorCommands(QtGui.QMainWindow):     ## Commands Renaming
        newConf['SMS_COMSUFFIX']    = self.ui.lineSuffix.text()
 
        newConf["COM_CHECK"]        = self.ui.lineCheck.text()
+       newConf["COM_STOLEN"]       = self.ui.lineStolen.text()
        newConf["COM_LOG"]          = self.ui.lineLog.text()   
        newConf["COM_LOCATION"]     = self.ui.lineLocation.text()
        newConf["COM_TRACKON"]      = self.ui.lineTrackOn.text()
@@ -724,6 +728,8 @@ class smsconEditorCommands(QtGui.QMainWindow):     ## Commands Renaming
        newConf["COM_UNLOCK"]       = self.ui.lineUnlock.text()
        newConf["COM_REMOTEON"]     = self.ui.lineRemoteOn.text()
        newConf["COM_REMOTEOFF"]    = self.ui.lineRemoteOff.text()
+       newConf["COM_SILENTON"]     = self.ui.lineSilentOn.text()
+       newConf["COM_SILENTOFF"]    = self.ui.lineSilentOff.text()
        newConf["COM_POWER"]        = self.ui.linePower.text()
        newConf["COM_REBOOT"]       = self.ui.lineReboot.text()
        newConf["COM_POWEROFF"]     = self.ui.linePowerOff.text()
@@ -930,7 +936,7 @@ class smsconEditorPasswordChange(QtGui.QDialog):
           message = 'The two cases are not equal. Try again.'
           showMessage(message)
           return
-       message = 'Storing new password, plase wait...'
+       message = 'Storing new password, please wait...'
        showQuickMessage(message)
 
        if NewPassword == '':
